@@ -11,7 +11,7 @@ use Readonly;
 
 use base qw(Exporter);
 
-$VERSION   = '0.07';
+$VERSION   = '0.08';
 @EXPORT_OK = qw(validate validateCVR generate _calculate_sum);
 
 use constant MODULUS_OPERAND => 11;
@@ -158,7 +158,7 @@ This documentation describes version 0.06 of Business::DK::CVR
             { callbacks =>
                 { 'validate_cvr' => sub { validateCVR($_[0]); } } } } );
         
-        print $_[1]." is a valid CVR\n";
+        print "$_[0] is a valid CVR\n";
     
     }
 
@@ -167,7 +167,7 @@ This documentation describes version 0.06 of Business::DK::CVR
 CVR is a company registration number used in conjuction with VAT handling in
 Denmark.
 
-If you want to use this module in conjunction please check:
+If you want to use this module with L<Data::FormValidator> please check:
 L<Data::FormValidator::Constraints::Business::DK::CVR>
 
 =head1 SUBROUTINES AND METHODS
